@@ -58,7 +58,6 @@ import java.util.List;
 import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import org.apache.commons.logging.Log;
 import org.apache.jsieve.SieveException;
 import org.apache.jsieve.parser.generated.Node;
 import org.apache.jsieve.parser.generated.ParseException;
@@ -74,7 +73,6 @@ import com.openexchange.jsieve.commands.RuleComment;
 import com.openexchange.jsieve.visitors.InternalVisitor;
 import com.openexchange.jsieve.visitors.Visitor;
 import com.openexchange.jsieve.visitors.Visitor.OwnType;
-import com.openexchange.log.LogFactory;
 import com.openexchange.mailfilter.ajax.Credentials;
 import com.openexchange.mailfilter.ajax.exceptions.OXMailfilterExceptionCode;
 
@@ -194,7 +192,7 @@ public final class SieveTextFilter {
 
     private static final String LEGAL_FLAG_CHARS = "[a-zA-Z1-9]";
 
-    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(SieveTextFilter.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(SieveTextFilter.class);
 
     private static final String RULENAME_TAG = "Rulename: ";
 
@@ -207,6 +205,10 @@ public final class SieveTextFilter {
     private static final String MATCH_STRING = "([^" + SEPARATOR_REGEX + "]*?)";
 
     private static final Pattern PATTERN = Pattern.compile("^" + FLAG_TAG + MATCH_STRING + SEPARATOR_REGEX + UNIQUE_ID + MATCH_STRING + SEPARATOR_REGEX + RULENAME_TAG + "(.*?)$");
+    
+    private static final String OK = "\nOK";
+    
+    private static final String ESCAPED_OK = "\n_OK_";
 
     private final String username;
 
@@ -222,9 +224,10 @@ public final class SieveTextFilter {
         boolean errorsinscript = false;
         // The following line strips off the first line of the script
         // final String first = readFileToString.replaceAll("^.*(\r)?\n", "");
-        final String commentedlines = diffremovenotcommentedlines(kickcommentsright(readFileToString), readFileToString);
+        final String unescaped = readFileToString.replaceAll(ESCAPED_OK, OK);
+        final String commentedlines = diffremovenotcommentedlines(kickcommentsright(unescaped), unescaped);
 
-        final Node uncommented = new SieveParser(new StringReader(readFileToString)).start();
+        final Node uncommented = new SieveParser(new StringReader(unescaped)).start();
         // final List<OwnType> jjtAccept = (List<OwnType>)
         // uncommented.jjtAccept(new Visitor(), null);
         // log.debug(jjtAccept);
@@ -233,16 +236,16 @@ public final class SieveTextFilter {
         // final List<OwnType> jjtAccept2 = (List<OwnType>)
         // commented.jjtAccept(new Visitor(), null);
         // log.debug(jjtAccept2);
-        final ArrayList<RuleComment> rulenames = getRulenames(readFileToString);
+        final ArrayList<RuleComment> rulenames = getRulenames(unescaped);
         final ArrayList<Rule> rules = (ArrayList<Rule>) uncommented.jjtAccept(new InternalVisitor(), Boolean.FALSE);
         final ArrayList<Rule> rules2 = (ArrayList<Rule>) commented.jjtAccept(new InternalVisitor(), Boolean.TRUE);
         // Attention: After merging the manipulation of finalrules also
         // manipulates rules and rules2
         final ArrayList<Rule> finalrules = mergerules(rules, rules2);
-        if (addRulenameToFittingCommandAndSetErrors(rulenames, finalrules, readFileToString, commentedlines)) {
+        if (addRulenameToFittingCommandAndSetErrors(rulenames, finalrules, unescaped, commentedlines)) {
             errorsinscript = true;
         }
-        final NextUidAndError nextuidanderror = setPosAndMissingErrortextsAndIds(finalrules, readFileToString, commentedlines);
+        final NextUidAndError nextuidanderror = setPosAndMissingErrortextsAndIds(finalrules, unescaped, commentedlines);
         if (nextuidanderror.isError()) {
             errorsinscript = true;
         }
@@ -329,9 +332,8 @@ public final class SieveTextFilter {
         }
         if (error) {
             return new ClientRulesAndRequire(retval, requires);
-        } else {
-            return new ClientRulesAndRequire(retval, new HashSet<String>());
         }
+        return new ClientRulesAndRequire(retval, new HashSet<String>());
     }
 
 
@@ -348,14 +350,10 @@ public final class SieveTextFilter {
             final Rule rule = finalrules.get(i);
             final RuleComment ruleComment = rule.getRuleComment();
             if (null != ruleComment) {
-                if (LOG.isDebugEnabled()) {
-                    LOG.debug("Added line number " + linenumber + " to comment " + ruleComment);
-                }
+                LOG.debug("Added line number {} to comment {}", linenumber, ruleComment);
                 ruleComment.setLine(linenumber++);
             }
-            if (LOG.isDebugEnabled()) {
-                LOG.debug("Added line number " + linenumber + " to rule " + rule);
-            }
+            LOG.debug("Added line number {} to rule {}", linenumber, rule);
             rule.setLinenumber(linenumber);
             // Here we add one because a space between two rules looks better
             final ArrayList<Command> commands = rule.getCommands();
@@ -534,7 +532,7 @@ public final class SieveTextFilter {
         int size = 0;
         if (null != actioncommands) {
             for (final ActionCommand actionCommand : actioncommands) {
-                if (Commands.VACATION.equals(actionCommand.getCommand()) || Commands.ENOTIFY.equals(actionCommand.getCommand())) {
+                if (Commands.VACATION.equals(actionCommand.getCommand()) || Commands.ENOTIFY.equals(actionCommand.getCommand()) || Commands.PGP_ENCRYPT.equals(actionCommand.getCommand())) {
                     // The text arguments for vacation end method for enotify are the last in the list
                     final ArrayList<Object> arguments = actionCommand.getArguments();
                     final int size2 = arguments.size();
@@ -641,11 +639,12 @@ public final class SieveTextFilter {
         for (final OwnType owntype : noncommentedoutput) {
             final int linenumber = owntype.getLinenumber();
             final String string = owntype.getOutput().toString();
+            final String escaped = string.replaceAll(OK, ESCAPED_OK);
             final int size = retval.size();
             if (linenumber > size + 1) {
                 fillup(retval, linenumber - (size + 1));
             }
-            retval.addAll(stringToList(string));
+            retval.addAll(stringToList(escaped));
         }
         for (final OwnType owntype : commentedoutput) {
             int linenumber = owntype.getLinenumber() - 1;
@@ -800,7 +799,7 @@ public final class SieveTextFilter {
     }
 
     private void printErrorForUser(final OXException mailfilterException) {
-        LOG.error("Error in mailfilter rules of user " + this.username + ": " + mailfilterException.getMessage(), mailfilterException);
+        LOG.error("Error in mailfilter rules of user {}", this.username, mailfilterException);
     }
 
     /**
